@@ -3,22 +3,27 @@ use warnings;
 
 package Dancer2::Plugin::UnicodeNormalize;
 {
-    $Dancer2::Plugin::UnicodeNormalize::VERSION = '0.033';
+    $Dancer2::Plugin::UnicodeNormalize::VERSION = '0.035';
 }
 
-use Dancer2 0.14300;
-use Dancer2::Plugin;
+use Dancer2::Plugin 0.150;
 use Unicode::Normalize;
 
 on_plugin_import {
     my $dsl = shift;
-    my $settings = plugin_setting();
 
+    # pre Plugin2 we need to get settings here
+    my $settings = plugin_setting;
     $dsl->app->add_hook(
         Dancer2::Core::Hook->new(
             name => 'before',
             code => sub {
-                for (@{$settings->{'exclude'}}) { return if $dsl->request->path =~ /$_/ }
+                # perhaps better ways to check for Plugin2 but this works
+                if ( $dsl->can('execute_plugin_hook')) {
+                    # Plugin2  - fetch fresh config on each run
+                    $settings = plugin_setting;
+                }
+                for (@{$settings->{'exclude'}}) { return if $dsl->app->request->path =~ /$_/ }
 
                 my $form = $settings->{'form'} || 'NFC';
                 my $normalizer = Unicode::Normalize->can($form);
@@ -29,11 +34,11 @@ on_plugin_import {
                 }
 
                 for (qw/query body route/) {
-                    my $p = $dsl->request->params($_);
+                    my $p = $dsl->app->request->params($_);
                     next unless $p;
                     %{$p} = map { $_ => $normalizer->($p->{$_}) } grep { $p->{$_} } keys %{$p};
                 }
-                $dsl->request->_build_params;
+                $dsl->app->request->_build_params;
             },
         ),
     );
@@ -52,7 +57,7 @@ Dancer2::Plugin::UnicodeNormalize - Normalize incoming Unicode parameters
 
 =head1 VERSION
 
-Version 0.033
+Version 0.035
 
 =head1 SYNOPSIS
 
@@ -66,6 +71,11 @@ silently before processing each route. By default, we use Unicode Normalization
 Form C - this is usually what you want. Other forms can be selected, see:
 L</"CONFIGURATION">.
 
+B<** NOTE **> This has been updated to build against Dancer2 0.200000 but
+operations do not yet apply to newer parameter access methods, query_parameters,
+body_parameters and route_parameters. This will be fixed in the next release.
+
+
 This plugin was inspired by L<Mojolicious::Plugin::UnicodeNormalize>. For
 information on why Unicode Normalization is important, please see:
 
